package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````V!8``#0```!PE`````0`!30`(``'
M`"@`&P`:``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!<````7````!`````$````!````````````````````H(X`
M`*".```%```````!``$```"@C@``H(X!`*".`0"X`@``)`,```8```````$`
M`@```*R.``"LC@$`K(X!`/````#P````!@````0````$````+`$``"P!```L
M`0``3````$P````$````!````%#E=&2DAP``I(<``*2'```,`0``#`$```0`
M```$````+W5S<B]L:6)E>&5C+VQD+F5L9E]S;P``!P````0````!````3F5T
M0E-$``#`K](U!`````0````#````4&%8```````'````"0````4```!.971"
M4T0``&5A<FUV-FAF`````&$```!L```````````````Q````#@``````````
M````.0````\```!!`````````#```````````P```$\```!D`````````"``
M``!.````!@```!X````5`````````$0```!9````8``````````8````/0``
M`%L```!E`````````&@```!J````+P```!,```!:````1@```!8```!?````
M2`````````!+````1P```#8```!>````)@```"H`````````!P```%``````
M````#````"P```!K````70```$T````A````40```&D`````````8@``````
M```9````+@```$(````````````````````2````,P`````````*````8P``
M`"L`````````"0`````````D````.@````````!2````!0```$D````<````
M/`````````````````````````!,`````````#L```!5````9@````````!G
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````!0`````````
M`````````````````````````````````````",````B`````````"D`````
M````"P```"<````H````+0``````````````#0`````````=````&P```#4`
M```:```````````````1`````````#0````R````.````!\`````````````
M``````````````````0```````````````````!#````)0``````````````
M`````!<`````````0````$4````(````````````````````/P````````!4
M``````````````!8```````````````^````5P````````!3`````````$H`
M```0``````````````!6````7````#<```!A````````````````````````
M````````````V!8````````#``L``````*B.`0```````P`1`)D`````````
M`````!(````,```````````````2````%```````````````$@```'H#```T
M(@``"````!(`"P`<```````````````B````*P``````````````$@```$,#
M`````````````!(````Q```````````````2````BP,``%B1`0``````$``5
M`#@``````````````!(```"9`P``U"D``"`````2``L`/P``````````````
M$@```%`#`````````````!(```!'```````````````2````M`,````T``!H
M````$@`+`(H``````````````!(```#(`P``Q)$!```````0`!4`3P``````
M````````$@```,`#``!8D0$``````!``%`!?```````````````2````;@``
M````````````$@```'0``````````````!(```![```````````````2````
MA0``````````````$@```(\``````````````!(```#'`P``Q)$!```````0
M`!4`F```````````````$@```%<"`````````````!(```">````````````
M```2````I0``````````````$@```+,``````````````!(```#$````````
M```````1````T0``````````````$@```-,#``"\)```,````!(`"P#@`P``
M["0``&`````2``L`[`,``.@J``"(!@``$@`+`-\``````````````!8```#R
M```````````````2````8@,`````````````$@```/T``````````````!(`
M```&`0``P)$!``0````1`!4`#@$`````````````$@```!<!````````````
M`!(````Y`P`````````````2````(P$`````````````$@```"H!````````
M`````!(```#Y`P``R$```!@!```2``L`/0$`````````````$0```$\!````
M`````````!(```!?`0`````````````2````;0$`````````````$@```'(!
M`````````````!$```"!`0`````````````2````!`0``%21`0`$````$0`4
M`)`!`````````````!(```"<`0`````````````2````L0$`````````````
M$@```+P!`````````````!(```!U`P``Q)$!```````0`!4`\P(`````````
M````$@```,\!`````````````!(```!'!```V!8````````2``L`W0$`````
M````````$@```.4!`````````````"(```#]`0`````````````2````"0(`
M````````````$@````X$``#$D0$``````!``%0`6!```3"4``,P!```2``L`
M#P(`````````````(@```"4"`````````````!(````P`@`````````````2
M````(P0``.!!``!X`0``$@`+`$$"`````````````!(````M!```6)$!````
M```0`!4`.00``%0A``!H````$@`+`$$$```T1```E`(``!(`"P!(`@``````
M```````2````1@0``-@6````````$@`+`$\"`````````````!(```!.!```
M/"(``(`"```2``L`6P0``/0I``#T````$@`+`%8"`````````````!(```!M
M!```&"<``(`````2``L`7P(`````````````$@```'`"`````````````!(`
M```"`P`````````````2````=P(`````````````$@```'L$``"8)P``7```
M`!(`"P"&`@`````````````2````CP(`````````````$@```)4"````````
M`````!(````L`P`````````````2````F@(`````````````$@```!\#``"$
MD0$`!````!$`%0"B`@`````````````2````5P,`````````````$@```*D"
M`````````````!(```"#!```:$```&`````2``L`L`(`````````````$@``
M`+\"`````````````!$````4`P``$)$!``0````1`!0`C`0``'`Q``"0`@``
M$@`+`#8!`````````````!(```#$`@`````````````2````:0,`````````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!?7V-X85]F:6YA
M;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC;7``<W1R<F-H<@!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O<G0`=6YL:6YK`%]?;'-T
M870U,`!P97)L7V9R964`7U]S=&%T-3``7V5X:70`;65M8W!Y`'!E<FQ?9&5S
M=')U8W0`7U]S=&%C:U]C:&M?9F%I;`!03%]D;U]U;F1U;7``4&5R;%]S=E]S
M971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E
M;G9I<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A9F5S
M>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V`%]?
M<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I;FET
M,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE=UA3
M`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`7U]D
M97)E9VES=&5R7V9R86UE7VEN9F\`4&5R;%]M9U]S970`;6MD:7(`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`'!E<FQ?<&%R<V4`4&5R;%]N97=84U]F;&%G<P!A
M8V-E<W,`9V5T<&ED`&UE;6-H<@!V9G!R:6YT9@!097)L7V%T9F]R:U]L;V-K
M`&UE;6-M<`!097)L7W-V7W-E='!V;@!P97)L7W)U;@!L<V5E:P!O<&5N`'-P
M<FEN=&8`9V5T=6ED`'-T<FQE;@!?7W1L<U]G971?861D<@!?7W-&`'-T<F-M
M<`!L:6)M+G-O+C``;&EB8W)Y<'0N<V\N,0!L:6)P=&AR96%D+G-O+C$`<'1H
M<F5A9%]A=&9O<FL`<W1R9'5P`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S
M7W-T<FEN9W,`7U]G971P=W5I9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`
M871E>&ET`%]L:6)C7VEN:70`<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R
M7V-U<G)E;G1?97AE8P!?7V)S<U]S=&%R=%]?`&=E=%]U<V5R;F%M95]F<F]M
M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!?7V)S<U]E;F1?7P!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M;7E?<&%R7W!L`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?7V)S
M<U]S=&%R=`!X<U]I;FET`&UA:6X`7U]S=&%R=`!P87)?9FEN9'!R;V<`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!P87)?9&EE`'-H85]I;FET
M`%A37TEN=&5R;F%L<U]005)?0D]/5``O=7-R+W!K9R]L:6(O<&5R;#4O-2XS
M."XP+V5A<FUV-FAF+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K
M9R]L:6(``*".`0`7````I(X!`!<```"TD`$`%P```+R0`0`7````Q)`!`!<`
M``#4D`$`%P```-B0`0`7````X)`!`!<```#HD`$`%P```/B0`0`7`````)$!
M`!<````(D0$`%P````R1`0`7````$)$!`!<````4D0$`%P```"21`0`7````
M*)$!`!<````PD0$`%P```#21`0`7````.)$!`!<````\D0$`%P```$"1`0`7
M````2)$!`!<```!,D0$`%P```%21`0`7````N)`!`!4'``#`D`$`%10``,B0
M`0`5(@``S)`!`!$G``#0D`$`$B<``-R0`0`5,@``Y)`!`!4V``#LD`$`%3P`
M`/"0`0`50@``])`!`!5'``#\D`$`%58```21`0`59@``J(\!`!8#``"LCP$`
M%@0``+"/`0`6!0``M(\!`!8'``"XCP$`%@@``+R/`0`6"0``P(\!`!8*``#$
MCP$`%@P``,B/`0`6#@``S(\!`!8/``#0CP$`%A```-2/`0`6$@``V(\!`!86
M``#<CP$`%A<``."/`0`6&```Y(\!`!89``#HCP$`%AH``.R/`0`6&P``\(\!
M`!8=``#TCP$`%AX``/B/`0`6'P``_(\!`!8@````D`$`%B$```20`0`6(P``
M")`!`!8H```,D`$`%BD``!"0`0`6*@``%)`!`!8L```8D`$`%BT``!R0`0`6
M+@``()`!`!8O```DD`$`%C```"B0`0`6,P``+)`!`!8T```PD`$`%C4``#20
M`0`6-P``.)`!`!8Y```\D`$`%CH``$"0`0`6.P``1)`!`!8^``!(D`$`%C\`
M`$R0`0`600``4)`!`!9"``!4D`$`%D,``%B0`0`61```7)`!`!9'``!@D`$`
M%D@``&20`0`620``:)`!`!9+``!LD`$`%D\``'"0`0`640``=)`!`!94``!X
MD`$`%E<``'R0`0`66```@)`!`!99``"$D`$`%EL``(B0`0`67```C)`!`!9=
M``"0D`$`%EX``)20`0`67P``F)`!`!9A``"<D`$`%F(``*"0`0`68P``I)`!
M`!9E``"HD`$`%FD``*R0`0`6:@``L)`!`!9K```$X"WE!."?Y0[@C^`(\+[E
M['L!``#&C^(7RHSB[/N\Y0#&C^(7RHSBY/N\Y0#&C^(7RHSBW/N\Y0#&C^(7
MRHSBU/N\Y0#&C^(7RHSBS/N\Y0#&C^(7RHSBQ/N\Y0#&C^(7RHSBO/N\Y0#&
MC^(7RHSBM/N\Y0#&C^(7RHSBK/N\Y0#&C^(7RHSBI/N\Y0#&C^(7RHSBG/N\
MY0#&C^(7RHSBE/N\Y0#&C^(7RHSBC/N\Y0#&C^(7RHSBA/N\Y0#&C^(7RHSB
M?/N\Y0#&C^(7RHSB=/N\Y0#&C^(7RHSB;/N\Y0#&C^(7RHSB9/N\Y0#&C^(7
MRHSB7/N\Y0#&C^(7RHSB5/N\Y0#&C^(7RHSB3/N\Y0#&C^(7RHSB1/N\Y0#&
MC^(7RHSB//N\Y0#&C^(7RHSB-/N\Y0#&C^(7RHSB+/N\Y0#&C^(7RHSB)/N\
MY0#&C^(7RHSB'/N\Y0#&C^(7RHSB%/N\Y0#&C^(7RHSB#/N\Y0#&C^(7RHSB
M!/N\Y0#&C^(7RHSB_/J\Y0#&C^(7RHSB]/J\Y0#&C^(7RHSB[/J\Y0#&C^(7
MRHSBY/J\Y0#&C^(7RHSBW/J\Y0#&C^(7RHSBU/J\Y0#&C^(7RHSBS/J\Y0#&
MC^(7RHSBQ/J\Y0#&C^(7RHSBO/J\Y0#&C^(7RHSBM/J\Y0#&C^(7RHSBK/J\
MY0#&C^(7RHSBI/J\Y0#&C^(7RHSBG/J\Y0#&C^(7RHSBE/J\Y0#&C^(7RHSB
MC/J\Y0#&C^(7RHSBA/J\Y0#&C^(7RHSB?/J\Y0#&C^(7RHSB=/J\Y0#&C^(7
MRHSB;/J\Y0#&C^(7RHSB9/J\Y0#&C^(7RHSB7/J\Y0#&C^(7RHSB5/J\Y0#&
MC^(7RHSB3/J\Y0#&C^(7RHSB1/J\Y0#&C^(7RHSB//J\Y0#&C^(7RHSB-/J\
MY0#&C^(7RHSB+/J\Y0#&C^(7RHSB)/J\Y0#&C^(7RHSB'/J\Y0#&C^(7RHSB
M%/J\Y0#&C^(7RHSB#/J\Y0#&C^(7RHSB!/J\Y0#&C^(7RHSB_/F\Y0#&C^(7
MRHSB]/F\Y0#&C^(7RHSB[/F\Y0#&C^(7RHSBY/F\Y0#&C^(7RHSBW/F\Y0`0
MH.$"`*#A!]#-XSD``.H-P*#A,-@MZ40@G^5$,)_E`B"/X$!`G^4#,)+G!$"/
MX`,`5.$$L$SB,*B=*`-0@^($,(3B`U!%X`-0Q>,#4(7@!#"4Y#/_+^$%`%3A
M^___&C"HG>B<>`$`&`$``)AW`0`-P*#A\-@MZ6P@G^5L$)_E;#"?Y0(@C^`!
M0)+G`S"2YP2P3.(#`%3A\*B=*`0@U.6@`%+C#P``&@A`A.('<(/B!'!'X`=P
MQ^,$<(?@"%`4Y01@H.$`,)7E,_\OX0<`5.$``(7E\*B="`0PUN4(0(3BH`!3
MX_3__PHB___K.'@!`#P!```@`0``#<"@X8#8+>EP@9_E!+!,X@S03>(`8%'B
M"("/X$L```I<,9_E`""6Y0,0F.=4,9_E`,"2Y0!@@>4#<)CG"#"6Y0``7.,`
M,(?E.@``"C@QG^4#$)CG`,"!Y0`@DN4`,-+E``!3XP4```H!((+B+P!3XP`@
M@04!,-+D``!3X_K__QH``%#C````"O#^_^N+___K^#"?Y0,PF.<``%/C-0``
M"NPPG^7L0)_E`S"8YP1`C^`#`%3A"```*@-0@^($,(3B`U!%X`-0Q>,#4(7@
M!#"4Y#/_+^$%`%3A^___&K@`G^6X0)_E``"/X-C^_^NP,)_E!$"/X`,PF.<#
M`%3A"```*@-0@^($,(3B`U!%X`-0Q>,#4(7@!#"4Y#/_+^$$`%7A^___&@`@
ME^4`$);E!`"6Y<L*`.NJ_O_K3""?Y60PG^4"()CG`S"/X``P@N7+___J$R"@
MXU`PG^4`((WE`S"/X`(@H.,$`*#C`!"@X_/^_^L!`*#CT/[_ZW[__^O'___J
MK'<!`&0!```X`0``;`$``%P!```H`0``''8!`"S^___8=0$`1`$``&1X`0"4
M+0``#<"@X=0PG^7PVRWI`(!0X@2P3.(!<*#A`S"/X"L```J\()_E`C"3YP"0
MD^4``%GC*```"@`PV.4]4%/B`5"@$P``4^,`4*`#``!5XQ$``!H`0)GE``!4
MXPP```H)8*#A!2"@X0@0H.$$`*#AB/[_ZP``4.,"```:!3#4YST`4^,+```*
M!$"VY0``5./S__\:!`"@X?"KG>@(4*#A`3#UY0``4^,]`%,3^___&@A01>#F
M___J"6!&X`%0A>)&8:#A!4"$X`!@A^4$`*#A\*N=Z`A`H.'M___J"4"@X>O_
M_^K\=0$`.`$```W`H.'PV"WI!+!,X@C03>(`4*#A@'"?Y8`PG^4'<(_@`V"7
MYR1`2^(`,);E(#`+Y000H.$%`*#AMO__ZP``4.,.```*6#"?Y200&^4#,)?G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___J("`;Y0`PEN4#`%+A`0``&AS02^+PJ)WH;?[_ZQ!U`0!``0``.`$```W`
MH.'PWRWI!+!,XJS03>(T,9_E-"&?Y0,PC^`"0)/G`&!0X@`PE.4P,`OE`@``
M"@`PUN4``%/C!0``&C`@&^4`,)3E`P!2X3X``!HHT$OB\*^=Z&;^_^L`<%#B
M]O__"NPPG^7L@)_E`S"/X.B0G^70,`OES#!+X@B`C^`)D(_@U#`+Y0<`H.'+
M_O_K``!0XR4```H-4(#B!0"@X0@0H.'"_O_K``!0X_7__PH)$*#A!0"@X;W^
M_^L``%#C\/__"@8`H.&P_O_K`*"@X04`H.&M_O_K``"*X`(`@.*P_O_K`*"@
MX04PH.$&(*#AT!`;Y9S^_^O4$!OE"@"@X1O^_^L!`'#C"@"@X0,```K$,!OE
M#SH#X@$)4^,(```*"O[_ZPH`H.'__?_KU?__Z@<`H.$I_O_K!@"@X>7]_^N^
M___JKO__Z_7__^H7_O_K;'0!`$`!``!X*P``8"L``&`K```-P*#A\-\MZ02P
M3.(4T$WB`4"@X0R2G^4,,I_E`"#1Y0F0C^`#8)GG/0!2XP%`@0(`,);E`%"@
MX00`H.$P,`OE>?[_ZS002^(`<*#A!0"@X2[__^L`@%#B/@``"G+^_^L'`%#A
M-0``*L`QG^4T@!OE`Y"9YPB!H.$`,-7E/0!3X@$`H!,``%/C``"@`P``4.,%
M```*!0"@X0$P\.4``%/C/0!3$_O__QH%`$#@`G"'X@``A^``<)GE8?[_ZP``
M4.,(`(?G5```"@`PU>4`()GE/0!3XP``4Q,T$!OE`0"%X@$1DN<`,,'E!@``
M"@$@@>(!,-#D`A"@X3T`4^,``%,3`3#"Y/G__QH],*#C`2"@X0`PP>4!,-3D
M``!3XP$PXN7[__\:``"@XS`@&^4`,);E`P!2X3H``!HHT$OB\*^=Z`$P2.(!
M(-3D``!2XP$@X^7[__\:\O__ZM`PG^4#D)GG`""9Y0"@DN4``%KC"!"@`PD`
M``H(,*#A`A"@X0```.H*,*#A!`"QY0&@@^(``%#C^O__&@,P@^(#$:#AD#"?
MY0,PC^```)/E``!0XQ,``!H!P*#C`0"@X0#`@^4\(`OE'_[_ZP`P4.(X,`OE
M$@``"CP@&^4*@:#A`A"@X0@@H.%=_?_K.#`;Y0`PB>4`$*#C`2"*X@(1@^<T
MH`OEG?__Z@(`H.%1_?_K``!0XP`PH.$``(GE"H&@$?/__QH``.#CP/__ZHC]
M_^L$<P$`0`$``#@!``"8<P$`#<"@X3#8+>D$L$SBH-!-XG`PG^5P()_E`S"/
MX`)`D^>T$$OB`#"4Y0!0H.$8,`OE8OW_ZP``4.,``*`3!```&JPP&^4/.@/B
M"@I3XP$)4Q,%```*&"`;Y0`PE.4#`%+A!P``&A302^(PJ)WH!0"@X0(0H..T
M_?_K$`]OX:`"H.'S___J8OW_Z]1P`0!``0``#<"@X?#;+>D$L$SB0=Y-XO0P
MG^5"SDOB",!,XNP@G^4#,(_@,,0+Y0)0D^<`<*#AW`"?Y0`PE>4!D*#AU""?
MY0P0H.$``(_@*#`+Y5O]_^L`@%#B(@``VKP`G^4!0$CB``"/X,']_^LD,$OB
M!#"#X`0T4^4`8)#E``!3XQ$```H(0*#A!""@X2\0H.,P!!OEC_W_ZP``4.,,
M```*!#"@X0<0H.$&`*#A,"0;Y93]_^LH(!OE`#"5Y0,`4N$1```:)-!+XO"K
MG>@``%3C[/__&@D@H.$'$*#A!@"@X2O]_^OR___J-`"?Y0``C^"?_?_K`&"0
MY0D@H.$'$*#A!@"@X2+]_^OI___J'?W_ZSQP`0!``0``?"<``/\#```L<0$`
MI'`!``W`H.$PV"WI`=M-X@2P3.((T$WBT#"?Y=`@G^4#,(_@`E"3YT%.2^((
M0$3B`#"5Y0`0H.$!*Z#C!`"@X1@P"^73_/_K!`!`X`$`0.(`,(3@!`!3X0H`
M`)H`(-3G+P!2XP<``!H`$*#C`@``Z@`@T^4O`%+C`@``&@$00^0$`%/A^?__
M&B\0H.,$`*#AS_S_ZP``4.,*```*!`!0X0`PH(,`,,"%!`"@X4G]_^L8(!OE
M`#"5Y0,`4N$*```:%-!+XC"HG>@8(!OE`#"5Y0,`4N$$```:&`"?Y0``C^`4
MT$OB,&B=Z#K]_^K<_/_K'&\!`$`!``"T)0``#<"@X?#8+>E$()_E1`"?Y40P
MG^4$L$SB`B"/X```C^`X4)_E.$"?Y0-@DN=(_?_K!5"/X`1`C^`%,*#A!B"@
MX000H.$``)#E'-!+XO!HG>CT_/_J*&X!`%1O`0`D`0``4"4``(0E```-P*#A
M,-@MZ50`G^4(T$WB!+!,X@``C^`S_?_K`%"@X0``D.7;___K`!"@XS1`G^4T
M,)_E!$"/X`,@E.<L,)_E``"5Y000C>4D$)_E`S"/X``PC>4!$(_@\_S_ZQ30
M2^(PJ)WH]&X!`*1M`0!P`0``\"<``!@E`````*#C'O\OX0W`H.'PWRWI$]U-
MX@2P3.(,T$WB-#*?Y30BG^4#,(_@`B"3YP!`H.$3?4OB)`*?Y0`PDN4,<$?B
M`6"@X0``C^`$$$?BX"0+Y3`P"^6\_?_K+Q"@XP!0H.$$`*#A6OS_ZP``4.,+
M```*[`&?Y000H.$``(_@;O[_ZP0`H.'@-!OE,"`;Y0`PD^4#`%+A;@``&BC0
M2^+PKYWH!@"@X=3\_^NX$9_E`1"/X'W\_^L`D%#B[/__"J@QG^6HH9_E`S"/
MX-PT"^6@,9_EH(&?Y0,PC^#D-`OEF#&?Y0J@C^`#,(_@V#0+Y0`PV>4``%/C
M/0``"@``5>,$```*"1"@X04`H.'?_/_K``!0XRT```H)`*#ATOS_ZP$00.(!
M,(G@`P!9X0!@H.$-```J`1#9YR\`4>,*```:``"@XP(``.H`(-/E+P!2XP(`
M`!H!`$/D`P!9X?G__QH)`*#AP/S_ZP!@H.$$`*#AO?S_ZP8`@.`!`(#B"`!0
MX;O__XK8-!OE0VY+X@0PC>4!*Z#C"C"@X0`0H.,(0(WE`)"-Y08`H.%8_/_K
M!Q"@X08`H.$E_/_K``!0XP,``!K$-!OE#SH#X@()4^,2```*K!"?Y0``H.,!
M$(_@,_S_ZP"04.*B__\*`##9Y0``4^/!__\:``!5XQ,```K<%!OE!0"@X:'\
M_^L``%#C`6"@$]R4&Q7M__\*T___Z@$0H.,&`*#A9OS_ZP``4./G__\:4`"?
MY080H.$``(_@__W_ZP8`H.%M_/_KCO__Z@%@H./DE!OEQ/__Z@O\_^L\;0$`
M0`$``,@D``"@)```?"0``/`C``!,)```X",``/\#```0)P``5",``.0B```-
MP*#A+Q"@XS#8+>D$L$SB`$"@X=7[_^L``%#C`4"`$@0`H.$4T$OB,&B=Z%#\
M_^H-P*#A,-@MZ0!`4.($L$SB"@``"@`PU.4``%/C!P``"F+\_^L!`(#B`0M0
MXP@``(H$`*#A%-!+XC!HG>C+_O_J%`"?Y0``C^`4T$OB,&B=Z#O\_^H``*#C
M,*B=Z+@A```-P*#A<-@MZ02P3.(,T$WB7#&?Y5PAG^4#,(_@`E"3YU0!G^4`
M,)7E``"/X"`P"^4Y_?_K1`&?Y41AG^4``(_@-?W_ZSP!G^4&8(_@``"/X#']
M_^LP`9_E)$!+X@``C^`M_?_K)`&?Y0``C^`J_?_K'`&?Y0``C^`G_?_K%`&?
MY0``C^`D_?_K#`&?Y0``C^`A_?_K!@"@X1_]_^O\`)_E``"/X!S]_^OT`)_E
M``"/X!G]_^OL`)_E!!"@X0``C^#;_/_K`!!0X@$```H&`*#AD_W_Z]``G^4$
M$*#A``"/X-/\_^L`$%#B`@``"KP`G^4``(_@BOW_Z[0`G^4$$*#A``"/X,K\
M_^L`$%#B#0``"J``G^4``(_@@?W_ZY@0G^68`)_E`1"/X```C^!\_?_K("`;
MY0`PE>4#`%+A"P``&AC02^)PJ)WH=`"?Y000H.$``(_@MOS_ZP`04.+N__\*
M8`"?Y0``C^!M_?_KZO__ZG[[_^LP:@$`0`$``/0A``#L(0``)"(``.0A``#@
M(0``W"$``.`A``!T(0``U"$``-@A``!4(0``R"$``+PA``"\(0``N"$``.`@
M``"X(0``'"$``'@A``#\(```#<"@X1#8+>D$L$SB#-!-XEPPG^5<()_E`S"/
MX`)`D^=4`)_E`""4Y1P02^(``(_@&"`+Y8O\_^L``%#C!0``"@``T.4``%#C
M,`!0$P$`H`,``*`3`0`@XA@@&^4`,)3E`P!2X0$``!H0T$OB$*B=Z$O[_^MD
M:`$`0`$``&@@```-P*#A#P`MZ0#8+>D4L$SB"-!-XC0PG^4T$)_E`S"/X`$`
MD^<(((OB``"0Y200G^44(`OE$``+Y0$`D^<$$)OEL`"`XHW[_^O_`*#C\OK_
MZ^!G`0!``0``:`$```W`H.'PWRWI`=A-X@2P3.(DT$WB`N"@XZ01G^6DP9_E
M`1"/X`P0D><!R$OB1,!,X@`0C.4`X(WE`!"1Y0`@H.,`,*#C`("@X3`0"^6#
M^__K`4!0X@!0P>+%;Z#A!@"@X0!PH./&'Z#A!F`DX``@5N!R8/_F`"`FX`$P
M)^``(%+@`3##X`)`5.`#4,7@``!4XP`PU>($8*#A!7"@X3\``+HD,9_E`2A+
MXB!1G^4#,(_@0"!"X@%(2^(4D9_E`#""Y050C^`X0$3B`!"@XP8@H.$',*#A
M`!"-Y0@`H.%?^__K`##@XP`@X.,#`%'A`@!0`2T```H)(*#A!!"@X0@`H.$4
M^__K`0!PXQH```H'`%#C&P``F@@`0.(`H)3@`P``.A<``.H!H$KB!`!:X10`
M`#H((*#C!1"@X0H`H.$[^__K``!0X_;__QH$0$K@!`"6X,0?I^`!.$OB1#!#
MX@`PD^4P(!OE`#"3Y0,`4N$3```:*-!+XO"OG>A8`)_E``"/X(?__^L`,.#C
M`6A6X@!PQ^)$()_E`P!7X0(`5@')__\:``#@XP`0X./I___J`3A+XD`P0^(`
M`)/E>?__Z\S__^K`^O_K@&<!`$`!``",'P``7&@!``@``0#,'@````#__PW`
MH.$`V"WI!+!,XB?[_^L@^__K``!0XP``D!4`J)WH#<"@X?#9+>D$L$SB%-!-
MXL0PG^7$()_E`S"/X`)`D^>\8)_E`#"4Y09@C^``4*#A+!!+X@8`H.$H,`OE
MTOO_ZP!P4.(%$*#A&0``"@`PU^4``%/C%@``"FKZ_^L``%#C%@``&@4`H.$.
M^__K`("@X0<`H.$+^__K``"(X`(`@.(.^__K`("@X5@PG^58$)_E`'"-Y04@
MH.$#,(_@`1"/X/?Z_^L($*#A!@"@X7+\_^L"``#J-`"?Y0``C^!N_/_K*"`;
MY0`PE.4#`%+A`0``&B#02^+PJ9WH>OK_ZXAE`0!``0``+!X``-`<``#0'```
MG!T```W`H.'PWRWI!+!,XDG?3>+XQ9_E^(6?Y0S`C^#T-9_E.`$+Y0B`C^`,
M((SB&$",XDMO2^)%[TOB`U"8YP<`DN@'`(;H#P"TZ`\`KN@#`)3H,,",XA).
M2^(#`([H!P"<Z`<`A.BP!9_E`#"5Y3Q1"^437DOB!1"@X0``C^`P,`OEA/O_
MZP!P4.("```*`##7Y0``4^.+```:D___ZP"@4.*-```*"@"@X<'Z_^N``*#A
M`0"`XL3Z_^L`(-KE`)"@X0``4N,)```*"4"@X4QUG^4'<(_@!`"@X0<0H.&K
M^O_K`2#ZY0)`A.(``%+C^/__&A0!&^4``%#C$@``"A%.2^("``#J!`"4Y```
M4.,-```*!1"@X5_[_^L`<%#B^/__"@`PU^4``%/C]?__"J/\_^L``%#C\O__
M"@<`H.&!^O_K`*!0XA<``!H`<*#C+#!+X@<Q@^``01/E``!4XPH```H`,-3E
M``!3XP<```H$`*#ADOS_ZP``4.,!<(?B!```&@=!EN<``%3C]/__&@"@H.,$
M``#J!`"@X6KZ_^L``%#CZ?__"@"@H.$*`*#A@/K_ZP!@H.$)`*#A??K_ZP``
MAN`!:X#B!&"&X@8`H.%^^O_K`$"@X4@TG^5(%)_E`S"/X``PC>5`-)_E"B"@
MX0,PC^`!$(_@!)"-Y63Z_^L$`*#A!QV@XS3Z_^L!`'#C&@``"OP02^($`*#A
MV/G_ZP!P4.(#```:]#`;Y0\Z`^(!"5/C00``"O0CG^7T$Y_E`@"8YS@A&^4$
M,*#A`""2Y;``@.(!$(_@U?G_ZP!@H.,\,1OE,"`;Y0`PD^4&`*#A`P!2X>4`
M`!HHT$OB\*^=Z`WZ_^L`,)#E$0!3X^#__PHX,1OE`&"@XP!0D^4&^O_KC#.?
MY0`0D.4#`)CG`!"-Y803G^4%(*#A!#"@X;``@.(!$(_@NOG_Z^3__^H/___K
M!P"@X1SZ_^L`8*#AW___Z@IPH.$'`93G``!0XPP```H%$*#AZ/K_ZP`P4.(!
M<(?B]___"@`PT^4``%/C]/__"@WZ_^L``%#C\?__"@"@H.%@___J#0"@XRCZ
M_^L,HY_E`)"@X0J@C^!3(*#C8O__ZN"0&^45^O_K``!9X;G__QKT,!OE@SN@
MX:,[H.$'#5/CM/__&@8`H.$8^O_K`&"@X<P"G^4%$*#A``"/X,;Z_^L`$%#B
M4```"C@Q&^4``)/E\/S_ZP!04.)+```*!0"@X03Z_^L#`%#C`("@X0P``)J0
M$I_E!`!`X@``A>`!$(_@!?K_ZP``4.,%```:!`!8XWX```H(@(7@!3!8Y2\`
M4^-Z```*$O[_ZP"@4.($```:!0"@X0H0H.'?^?_K`%!0XC0``!I`$I_E0`*?
MY0$0C^```(_@7/O_Z[_Y_^LP,I_E,!*?Y0,PC^`)`(WH*#*?Y2B2G^4H@I_E
M*%*?Y0,PC^`$(*#A`1"/X`8`H.'0^?_K"9"/X`B`C^`%4(_@#```ZI7Y_^L`
M,)#E$0!3XPT``!JI^?_K`7"'XH$`C>@(4(WE"3"@X00@H.$($*#A!@"@X;_Y
M_^L'':#C!@"@X8_Y_^L!`'#C[?__"@0`H.$H^?_KM`&?Y080H.$``(_@,OO_
MZP8`H.&1_O_K9/__ZC@Q&^4`4)/EL/__Z@S^_^L``%#C`##1X@"`H.$!D*#A
MQ/__N@H@4.(`,,'B`*"-Y04`H.%DH$OBF?G_ZPH0H.$&(*#C!0"@X5/Y_^L&
M`%#C`@``"D@!G^4``(_@X?W_ZT`QG^5D$!OE`S"/X`P@D^4,,(/B`@!1X:[_
M_QJT(-KAM##3X0,`4N&J__\:`!"@XS(@6.(`,,GB`!"-Y04`H.%<<$OB?OG_
MZP4`H.$'$*#A*""@XSCY_^LH`%#C`@``"N0`G^4``(_@QOW_ZP#`H./8,)_E
MV!"?Y0,PC^`$,(WET#"?Y0!PC>4#,(_@!""@X0$0C^`&`*#A-,!+Y7'Y_^NU
M___J.#$;Y02`D^4``%CC@/__"@@`H.%S^?_K`P!0XWS__YJ0$)_E!`!`X@``
MB.`!$(_@=?G_ZP``4.,(4*`!=/__ZO#X_^L09@$`B&0!`$`!``#@&P``J!P`
M`+`;``"0&P``5!T``&@!``"`&P``V!H``$`:``"P&@``=!H``#@9``"X&```
M\!H``!@:```(&P``]!H``!@:``"\&@``I!<``!P9``"\%@``L!@``'`9``"0
M&```D!D``#P8```-P*#A\-DMZ02P3.(,T$WB+#*?Y2PBG^4#,(_@`E"3YR0"
MG^4`()7E``"/X"@@"^5`^?_K`#"0Y1`"G^5D(-/E+&!+X@80H.$``(_@92##
MY>[Y_^L``%#C`@``"@`PT.4Q`%/C7@``"MO\_^O@`9_EX$&?Y0``C^`N^?_K
M!$"/X`00H.$`<*#A`S"@XP``D.4!(*#CROC_ZP!`4.(*```*##"4Y;`AG^4`
M$)/E`B"/X```E^6G^/_K##"4Y0`0D^4(,)'E`043XU$``!J,`9_EC$&?Y0``
MC^`6^?_K!$"/X`00H.$`<*#A`S"@XP``D.4!(*#CLOC_ZP!`4.()```*8`&?
MY080H.$``(_@O_G_ZP`@4.(V```*##"4Y0``E^4`$)/EB_C_ZSP!G^4\@9_E
M``"/X/_X_^LT$9_E`'"0Y0!`H.$!(*#C`1"/X`<`H.&G^/_K'"&?Y0`0H.$"
M((_@!P"@X7OX_^L`(*#C`#"4Y00!G^4&$*#A92##Y0``C^"B^?_K"("/X```
M4.,(`(CE"P``"@<=H..M^/_K`3"`XA$`4.,!`%,3'0``BB@@&^4`,)7E`P!2
MX1@``!H@T$OB\*F=Z`0`F.7J_?_K``!0XP@`B.7N__\:H`"?Y0``C^"&^/_K
M`3#0Y0``4^.>__\*G/__ZH@PG^4,()3E`S"/X`0PD^4``)+E`!"3Y>WZ_^O$
M___J``"7Y8KX_^NJ___J2?C_ZUP@G^4`,*#A6`"?Y0(@C^`&`)+I``"/X``0
MD>5N^/_K#%X!`$`!```L7P$`V!4``.!>`0!X%P``3!<``(!>`0`D%P``U!0`
M`"1>`0"T7@$`O!8``,`6``!4%```2!8``#Q>`0`(7@$`$!8```W`H.$PV"WI
M!+!,X@!`H.$U_/_K*/S_ZP!0H.&]_/_K``!0XP``5!,PJ)T(`##4Y0``4^,P
MJ)T()!"?Y04`H.$$(*#C`1"/X/'W_^L``%#C,*B=&`0`H.$4T$OB,&B=Z*KY
M_^HP%```#<"@X?#?+>D$L$SB5=]-XM`[G^70ZY_E`S"/X`[@D^==STOB#D"@
MX0P0H.$`0)3E>.$+Y1P@@.)<X(#B,$`+Y00PDN0S/[_F`@!>X00PH>7Z__\:
M=.!+XC@PG.4D0)SE#!"<Y00P(^`$(+SE`3`CX`(P(^#C/Z#A#@!<X4`PC.7T
M__\:!!"0Y6`[G^4(P)#E<"$;Y0!`D.5A8:#A$("0Y6P1&^4,X)#E!E`LX`,@
M@N`(((+@!%`%X`2`D.4#$('@#G`LX`Q0)>`.$('@`9"%X`AP!^!H$1OE9(&@
MX0YP)^#D+8+@!R""X&2A&^4#<('@"!`FX&)1H.$"$`'@#'"'X.(MB>`#H(K@
M!9`HX`80(>`'$('@!F"*X&)QH.$"D`G@8*$;Y>(M@>`(D"G@!Q`EX`:0B>`#
MH(K@`A`!X&)AH.'BG8G@"*"*X`4@(>!<$1OE!H`GX`H@@N#I+8+@`Z"!X`F`
M".!I$:#A6)$;Y0>`*.`%H(K@`5`FX`J@B.`#D(G@`H`%X`>0B>`&@"C@8E&@
MX>(MBN`)H(C@5($;Y05P(>`#D(C@`H`'X`:0B>`!@"C@8G&@X>(MBN`)H(C@
M4($;Y0=@)>`#D(C@`H`&X`&0B>`%@"C@8F&@X>(MBN`)H(C@3($;Y080)^`#
MD(C@`H`!X`60B>`'@"C@8A&@X>(MBN`)H(C@2($;Y0%0)N`#D(C@`H`%X`>0
MB>`&@"C@8E&@X>(MBN`)H(C@1($;Y05P(>`#D(C@`G`'X`:0B>`!<"?@8H&@
MX>(MBN`)H(?@0'$;Y0A@)>`#D(?@`G`&X&)AH.$%<"?@XBV*X`$0B>`\H1OE
M!I`HX`$0A^`"D`G@8G&@X0.@BN#B+8'@"!`IX#B1&^4%H(K@!U`FX`H0@>`#
MH(G@`I`%X`B`BN`&H"G@8E&@X0B@BN`T@1OEXAV!X`4@)^`#D(C@`2`"X&&!
MH.'AK8K@!F")X`<0(N`&$('@,&$;Y0@@)>`#D(;@ZAV!X&IAH.$*(`+@+*$;
MY0=PB>`%("+@!I`HX`<@@N`!D`G@`W"*X"BA&^7A+8+@!5"'X&$1H.$(D"G@
M`Z"*X`60B>`!4";@8G&@X>*=B>`"4`7@"""*X"2A&^4'@"'@!E`EX`F`".`"
M4(7@`S"*X)0HG^4@H1OE!C"#X`%@*.!I@:#AZ9V%X`-0AN`"8(K@"#`GX!RA
M&^4!$(;@"6`CX&DQH.'I787@!F"!X!B1&^4"$(K@`Z`HX`6@*N`'$('@97&@
MX>5MAN`*$('@`E")X!2A&^4'D"/@!I`IX`A0A>!F@:#AYAV!X`E0A>`"H(K@
M")`GX.%MA>`#,(K@`5`IX`50@^`0,1OE81&@X0R1&^4"H(/@`3`HX`>@BN`&
M,"/@9G&@X>9=A>`#,(K@`F")X`BA&^4'D"'@!9`IX`A@AN!E@:#AY3V#X`E@
MAN`(4"?@`I"*X`2A&^7C;8;@`1")X`-0)>!C,:#A`)$;Y050@>`"H(K@`Q`H
MX`>@BN`&$"'@9G&@X>9=A>`!$(K@`F")X/R@&^4'D"/@!9`IX`A@AN!E@:#A
MY1V!X`E@AN`(4"?@`I"*X/B@&^7A;8;@`S")X`%0)>!A$:#A])`;Y050@^`"
MH(K@`3`HX`>@BN`&,"/@9G&@X>9=A>`#,(K@`F")X/"@&^4'D"'@!9`IX`A@
MAN!E@:#AY3V#X`E@AN`(4"?@`I"*X.R@&^7C;8;@`1")X`-0)>!C,:#AZ)`;
MY050@>`"H(K@`Q`HX`>@BN`&$"'@9G&@X>9=A>`!$(K@`F")X.2@&^4'D"/@
M"&"&X`6`*>!ED:#AY1V!X`B`AN`"8(K@":`GX`,PAN`!8"K@!F"#X.`P&^7A
M78C@81&@X=R`&^4"H(/@`3`IX`>@BN`%,"/@97&@X>5MAN`#,(K@`E"(X-B@
M&^4'@"'@"5"%X`:`*.!FD:#A`J"*X.9M@^`(@(7@"3`GX-10&^7FC8C@`1"*
MX`8P(^!F8:#A`J"%X`,P@>`&$"G@:%&@X>@M@^`'<(K@`8`HX`0VG^4(H(?@
MT'`;Y040AN$#@(?@`A`!X&)QH.'B+8K@!:`&X`F0B.`*H('AS!`;Y0>`A>$)
MH(K@`H`(X`.0@>!B$:#AXBV*X`>@!>`&8(G@"J"(X<B0&^4!@(?A!J"*X`.0
MB>!B8:#A`H`(X.(MBN`!H`?@!5")X`J@B.'$D!OE!H"!X06@BN`#D(G@8E&@
MX0*`".#B+8K@!J`!X`=PB>`*H(CAP)`;Y06`AN$'H(K@`Y")X&)QH.$"@`C@
MXBV*X`6@!N`!$(G@"J"(X;R0&^4'@(7A`:"*X`.0B>!B$:#A`H`(X.(MBN`'
MH`7@!F")X`J@B.&XD!OE`8"'X0:@BN`#D(G@8F&@X0*`".#B+8K@`:`'X`50
MB>`*H(CAM)`;Y0:`@>$%H(K@`Y")X&)1H.$"@`C@XBV*X`:@`>`'<(G@"J"(
MX;"0&^4%@(;A!Z"*X`.0B>!B<:#A`H`(X.(MBN`%H`;@`1")X`J@B.&LD!OE
M!X"%X0&@BN`#D(G@8A&@X0*`".#B+8K@!Z`%X`9@B>`*H(CAJ)`;Y0&`A^$&
MH(K@`Y")X&)AH.$"@`C@XBV*X`&@!^`%4(G@"J"(X:20&^4&@('A!:"*X`.0
MB>!B4:#A`H`(X.(MBN`&H`'@!W")X`J@B.&@D!OE!8"&X0>@BN`#D(G@8G&@
MX0*`".#B+8K@!:`&X`$0B>`*H(CAG)`;Y0>`A>$!H(K@`Y")X&(1H.$"@`C@
MXBV*X`>@!>`&8(G@"J"(X9B0&^4!@(?A!J"*X`.0B>!B8:#A`H`(X.(MBN`!
MH`?@!5")X`J@B.&4D!OE!H"!X06@BN`#D(G@8E&@X0*`".#B+8K@!J`!X`=P
MB>`*H(CAD)`;Y06`AN$'H(K@`Y")X&)QH.$"@`C@XBV*X`6@!N`!$(G@"J"(
MX8R0&^4'@(7A`:"*X`.0B>!B$:#A`H`(X.(MBN`'H`7@!F")X`J@B.&(D!OE
M`8"'X0:@BN`#D(G@8F&@X0*`".#B+8K@`:`'X`60B>`*@(CA"8"(X(20&^4&
M4('A`S")X`=P@^`&D`'@]#*?Y0)0!>"`H!OEXHV(X`E0A>%B(:#A?)`;Y0=0
MA>`#<(K@`J`FX`B@*N`!$(?@:'&@X>A=A>`*$('@`X")X'B@&^4'D"+@!9`I
MX`:`B.!E8:#AY1V!X`F`B.`&4"?@`Y"*X'2@&^7AC8C@`B")X`%0)>!A$:#A
M<)`;Y050@N`#H(K@`2`FX`>@BN`(("+@:'&@X>A=A>`"((K@`X")X&R@&^4'
MD"'@!9`IX`9@B.!E@:#AY2V"X`E@AN`(4"?@`Y"*X&B@&^7B;8;@`1")X`)0
M)>!B(:#A9)`;Y050@>`#H(K@`A`HX`>@BN`&$"'@9G&@X>9=A>`!$(K@`V")
MX&"@&^4'D"+@!9`IX`A@AN!E@:#AY1V!X`E@AN`(4"?@`Y"*X%R@&^7A;8;@
M`B")X`%0)>!A$:#A6)`;Y050@N`#H(K@`2`HX`>@BN`&("+@9G&@X>9=A>`"
M((K@`V")X%2@&^4'D"'@!9`IX`A@AN!E@:#AY2V"X`E@AN`(4"?@`Y"*X%"@
M&^7B;8;@`1")X`)0)>!B(:#A3)`;Y050@>`#H(K@`A`HX`>@BN`&$"'@9G&@
MX>9=A>`!$(K@`V")X$B@&^4'D"+@"&"&X`6`*>!ED:#AY1V!X`B`AN`#8(K@
M":`GX`(@AN`!8"K@!F""X$0@&^7A78C@81&@X0.@@N!`@!OE`2`IX`>@BN`%
M("+@97&@X>5MAN`"((K@`U"(X#R@&^4'@"'@!H`HX`E0A>!FD:#AYBV"X`A0
MA>`#H(K@"8`GX.)MA>`!4(K@`A`HX#2@&^4!$(7@.%`;Y6(AH.$#@(7@`S"*
MX`)0*>!FH:#AYAV!X`=PB.`$,(/@"H`BX`90)>`!@"C@"3"#X`50A^#A787@
M"("#X.4]B.!A$8S@>$$;Y1#`D.4`,(#E`B",X#`P&^4$P)#E`$"4Y050C.`*
MX([@!`!3X0@0@.40((#E!%"`Y0S@@.4!```:*-!+XO"OG>@:]?_K%%L!`$`!
M``"9>8):H>O9;MR\&X_6P6+*#<"@X6``H.,PV"WI!+!,XHWU_^L`(*#C+!"?
MY2Q`G^4LX)_E+,"?Y0`0@.4H$)_E$$"`Z0S`@.40$(#E%""`Y1@@@.5<((#E
M,*B=Z`$C16>)J\WO_MRZF'94,A#PX=+##<"@X?#;+>D4,)#E`H"@X8(AH.$"
M,)/@`""@XP$@H",`8*#A``!2XQ@@D.5<`)#E`2""$J@N@N```%#C!+!,X@%`
MH.$8((;E%#"&Y1R0AN(.```*0%!@X@4`6.$(4*"Q``")X`4@H.';]/_K7#"6
MY0,PA>!``%/C7#"&Y?"KG1@&`*#A!8!(X`5`A.##_/_K/P!8XQD``-I`@$CB
M*%.@X0%PA>('<X3@!!"@X0DPH.%`((3B`$"1Y03@D>4(P)'E#`"1Y1`0@>("
M`%'A`$"#Y03@@^4(P(/E#`"#Y1`P@^+S__\:`4"@X08`H.&K_/_K!P!4X>O_
M_QH%767@!8.(X`00H.$)`*#A"""@X;+T_^M<@(;E\*N=Z`W`H.'PVRWI`4"@
MX7\0X.,48)3E'("$XJ8QH.$_,`/B`2"#XC@`4N,`4*#A&'"4Y02P3.(#$,CG
M`@"(X$D``-I`(&+B`!"@X[OT_^L$`*#AC/S_ZP@`H.$X(*#C`!"@X[7T_^LG
M/*#A)BR@X2<(H.$G%*#A6V#$Y50PQ.4F.*#A)F2@X54`Q.59,,3E!`"@X5=P
MQ.56$,3E6"#$Y5I@Q.5X_/_K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`,)3E(S2@
MX0(PQ>4`,)3E`S#%Y0<PU.4$,,7EMC#4X04PQ>4$,)3E(S2@X08PQ>4$,)3E
M!S#%Y0LPU.4(,,7ENC#4X0DPQ>4(,)3E(S2@X0HPQ>4(,)3E"S#%Y0\PU.4,
M,,7EOC#4X0TPQ>4,,)3E(S2@X0XPQ>4,,)3E#S#%Y1,PU.40,,7ELC'4X1$P
MQ>40,)3E(S2@X1(PQ>40,)3E$S#%Y2302^+P:YWH._3_ZC@@8N(`$*#C<?3_
MZ[K__^H-P*#A,-@MZ6`PG^5@0)_E`S"/X"0@T^4$0(_@``!2XP2P3.(PJ)T8
M`1"@XT0@G^4D$,/E`C"4YP``4^,"```*-#"?Y0,`G^<,]/_K+#"?Y0,PE.<`
M`%/C,*B=""``G^4``(_@%-!+XC!HG>AX]/_J&$X!`"1,`0`<`0``<$T!`%0!
M``!T10``/!"?Y3PPG^4!$(_@`"#1Y0,PC^```%+C'O\O$0$`H.,D()_E``#!
MY0(PD^<``%/C'O\O`10`G^4$$('B``"/X&KT_^J830$`I$L!`%@!```010``
M#<"@X?#8+>D$L$SB(-!-XBQ2G^4L,I_E!5"/X"@`"^4L$`OE,"`+Y0-`E><P
M($OB`#"4Y2P02^(H`$OB(#`+Y3?T_^L`(I_E`#*?Y0(@E><#`)7G`A"@X3WT
M_^OP,9_E`S"5YP!@T^4``%;C3P``"N`!G^4``(_@??3_ZP`@D.4H8!OE1C/2
MY00`AN(#,(/C!P%PXT8SPN4#8(;B6```B@`!H.$2]/_K`,"@X2PP&^6D(9_E
MI!&?Y0``D^4"((_@!,""Y0$0C^"4(9_E``",Y000C.4"$)7G*"`;Y0``D>6`
M$9_E`0!2XP$0C^#X`,SA$!"@TP@``-H$X$/B`N&.X`P0C.($`+/E#@!3X00`
MH>7[__\:`R""X@(1H.$`X*#C1%&?Y0'@C.=`$9_E!5"/X`P`E>4&(*#A`."-
MY0PPH.$!$(_@%_3_ZP``4.,I```*'%&?Y21@2^(%4(_@#`"5Y<7S_^L`<*#A
M"`&?Y080H.$``(_@]/3_ZP``4.,8```*]#"?Y0,PC^`,`)/EJ_/_Z_+S_^L@
M(!OE`#"4Y0<`H.$#`%+A(P``&AS02^+PJ)WHNO/_Z\0PG^4``%#C`S"/X`P`
M@^4<```*D//_Z[``G^4``(_@)O3_ZP`PD.7F9</EHO__Z@@`E>4``%#C"0``
M"G7[_^OA___J#`"5Y03T_^O2___J?#"?Y7P`G^4#$)7G``"/X,CS_^MP`)_E
M!A"@X0``C^#(]/_K``!0XP@`A>72__\*[?__ZI+S_^L!`*#C3O/_ZTA+`0!`
M`0``4`$``&`!```L`0``'$P!`+A,`0`$!0``3`$``.0$``!(3`$`0-S__QQ,
M`0#\`0``\$L!`+A+`0#`2@$`2`$``/@"``#L````<'-?<W1R:6YG<R!M:7-S
M:6YG"@!P97)L>'-I+F,`````0T%#2$4``"X````N+@``)7,O)7,````O<')O
M8R]C=7)P<F]C+V5X90```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5`````!005)?5$5-4`````!005)?4%)/1TY!
M344`````.@```"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),-4]0
M5`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%
M0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````,0```&QS965K(&9A:6QE
M9`````!R96%D(&9A:6QE9`!,1%],24)205)97U!!5$@`4UE35$5-```E,#)X
M`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``4$%42`````!P87)L
M`````"YP87(`````<VAO<G0@<F5A9```)7,E<V-A8VAE+25S)7,``"5S)7-T
M96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````!@```!P97)L`````#``
M``!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`U.0```%5N86)L92!T;R!C
M<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M````+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`5$U0`"]T
M;7`O````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K
M86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I
M>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B
M7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH
M(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")0
M2UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]
M($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M
M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT
M:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@
M)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L
M96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@
M)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S
M("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE
M;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL
M="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A
M<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@
M*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO
M9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V
M+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@
M8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N
M86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*
M7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]
M('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE
M*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=
M*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N
M<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T
M(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC
M(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P
M.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F
M(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").
M;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q
M6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L
M("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@
M)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O
M9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T
M96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[
M("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B
M1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F
M+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F
M=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL
M;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF
M7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X
M="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI
M>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT
M(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U
M;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^
M("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*
M<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H
M)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O
M<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T[
M"G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M
M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L
M92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE
M.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D
M:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E
M*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I
M.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF
M:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR
M971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T
M(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F
M:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F
M:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I
M<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)
M0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@
M;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P
M87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?
M34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=
M.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97([
M"FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?
M1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92![
M"FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T
M;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X[
M"F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R
M;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S
M*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II
M<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T
M(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#
M3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*
M;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?
M;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA
M;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*
M?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F
M:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B
M)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP
M(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK
M4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C
M=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D[
M"GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R
M(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T
M7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`
M7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A
M=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@
M*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB
M.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER
M92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q
M=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*
M<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR
M97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A
M8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@
M+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@
M)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J
M(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H
M95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII
M9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P
M*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*
M+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I
M('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM
M(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A
M9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O
M9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*
M?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*
M)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L
M:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E
M*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL
M97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M
M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I
M"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG
M+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P
M<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5]
M.PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[
M<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER
M(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I
M<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@
M7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]0
M4D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T
M8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E
M=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ
M=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B
M?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%2
M7T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U
M:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS
M92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@
M0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z
M.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI
M.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@
M7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@
M<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B
M.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O
M9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?
M7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?
M15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/
M4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,["`$``"````!$C___
M(`$``*2/__]$`0``+)#__VP!``#<D?__U`$``,22__\``@``;)/__S`"``#,
ME/__9`(```27__^<`@``E)?__\@"``"XF/___`(``+"9__\X`P``&)K__W`#
M``"0FO__F`,``)B:__^L`P``&)W__^0#``!(G?__%`0``*B=__]8!```=)__
M_X@$``#TG___L`0``%"@___8!```,*+__Q`%``!0HO__,`4``$2C__]D!0``
MS*G__YP%``!<K/__T`4``,2L__\P!@``Q+C__V@&```DN?__C`8``#RZ__^X
M!@``M+O__Z0!```\O/__D`$``)"\__\`!@``$``````````!>E(``GP.`1L,
M#0`@````&````!R.__]@`````$(-#$B$!H4%BP2-`XX"2@P+!``D````/```
M`%B.__^(`````$(-#$J$"(4'A@:'!8L$C0..`D8,"P0`(````&0```"XCO__
ML`$```!"#0Q$AP6+!(T#C@)"#`L$````$````(@```"DNO__5``````````L
M````G`````BZ__^(`````$(-#$2$!H4%BP2-`XX"3`P+!&(,#1A"SLW+Q<0.
M!``H````S`````"0___H`````$(-#$2$"H4)A@B'!X@&B06+!(T#C@)$#`L$
M`"P```#X````O)#__Z@`````0@T,0H0(A0>&!H<%BP2-`XX"0@P+!`)$"@P-
M($(+`#`````H`0``-)'__V`!````0@T,0H0+A0J&"8<(B`>)!HH%BP2-`XX"
M0@P+!&(*#`TL0@LT````7`$``&"2__\X`@```$(-#$*$"X4*A@F'"(@'B0:*
M!8L$C0..`D(,"P0"F`H,#2Q""P```"@```"4`0``8)3__Y``````0@T,0H0&
MA06+!(T#C@)"#`L$;@H,#1A""P``,````,`!``#$E/__)`$```!"#0Q"A`J%
M"88(AP>(!HD%BP2-`XX"0@P+!`)<"@P-*$(+`#@```#T`0``M)7___@`````
M0@T,0H0&A06+!(T#C@)$#`L$`E@*#`T80@M."@P-&$+.S<O%Q`X$0@L``#0`
M```P`@``<);__V@`````0@T,2(0(A0>&!H<%BP2-`XX"0@P+!%H,#2!"SLW+
MQ\;%Q`X$````)````&@"``"@EO__>`````!"#0Q$A`:%!8L$C0..`D0,"P1F
M#`T8`!````"0`@``\);__P@`````````-````*0"``#DEO__@`(```!"#0Q"
MA`N%"H8)APB(!XD&B@6+!(T#C@)$#`L$`D(*#`TL0@L````L````W`(``"R9
M__\P`````$(-#$2$!H4%BP2-`XX"0@P+!$P,#1A"SLW+Q<0.!`!`````#`,`
M`"R9__]@`````$(-#$*$!H4%BP2-`XX"1`P+!%0*#`T80L[-R\7$#@1""T8*
M#`T80L[-R\7$#@1""P```"P```!0`P``2)G__\P!````0@T,0H0'A0:&!8L$
MC0..`D(,"P0"G`H,#1Q""P```"0```"``P``Y)K__X``````0@T,0H0%BP2-
M`XX"0@P+!'`*#`T40@LD````J`,``#R;__]<`````$(-#$2`!($#@@*#`8L(
MC0>.!D(,"Q0`-````-`#``!PF___X`$```!"#0Q"A`N%"H8)APB(!XD&B@6+
M!(T#C@)$#`L$`K(*#`TL0@L````<````"`0``!B=__\@`````$(-#$*+!(T#
MC@)"#`L$`#`````H!```&)W___0`````0@T,0H0)A0B&!X<&B`6+!(T#C@)"
M#`L$`F0*#`TD0@L````T````7`0``-B=__^(!@```$(-#$*$"X4*A@F'"(@'
MB0:*!8L$C0..`D(,"P0#-@$*#`TL0@L``#````"4!```**3__Y`"````0@T,
M0H0)A0B&!X<&B`6+!(T#C@)"#`L$`MH*#`TD0@L````L````R`0``(2F__]H
M`````$(-#$*$!H4%BP2-`XX"0@P+!&@,#1A"SLW+Q<0.!``L````^`0``(BV
M__^4`@```$(-#$*$"(4'A@:'!8L$C0..`D(,"P0"T`H,#2!""P`T````*`4`
M`(RF__\`#````$(-#$*$"X4*A@F'"(@'B0:*!8L$C0..`D(,"P0#Z@4*#`TL
M0@L``"````!@!0``5++__V``````0@T,1(0&A06+!(T#C@)"#`L$`"@```"$
M!0``D++__Q@!````0@T,1(0*A0F&"(<'B`:)!8L$C0..`EH,"P0`/````+`%
M``!\L___>`$```!"#0Q"A`J%"88(AP>(!HD%BP2-`XX"5@P+!`*6"@P-*$+.
MS<O)R,?&Q<0.!$(+``````#@0P``6$,````````!`````0````$```#+`@``
M`0```-4"```!````XP(```$````)`P``#P```*($```9````H(X!`!L````$
M````&@```*2.`0`<````!`````0```!X`0``!0```'0+```&````M`0```H`
M``#K!```"P```!`````5``````````,```"<CP$``@```!@"```4````$0``
M`!<```"($0``$0```&`0```2````*`$``!,````(````^___;P````CZ__]O
M&0````````````````````````````````````````````````````````"L
MC@$```````````"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3
M``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,`
M`*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``
MH!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@
M$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3
M``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,``*`3``"@$P``H!,`
M`*`3``"@$P``J(X!``````!X$0```````*".`0````````````````#`D0$`
M>!$```````"DC@$``````%21`0````````````````"LC@$``````(21`0``
M````$)$!`'`Q``"`D0$`%)$!``I005(N<&T*`````"Q*``#P1@````````!(
M```$2```($H``$Q'```H2@````````Q*```42@```````#1*``!'0T,Z("A.
M971"4T0@;F(T(#(P,C`P.#$P*2`W+C4N,`!'0T,Z("AN8C0@,C`R,#`X,3`I
M(#<N-2XP`"1.971"4T0Z(&-R=#`N4RQV(#$N-"`R,#$X+S$Q+S(V(#$W.C,W
M.C0T(&IO97)G($5X<"`D`"1.971"4T0Z(&-R=#`M8V]M;6]N+F,L=B`Q+C(S
M(#(P,3@O,3(O,C@@,C`Z,3(Z,S4@8VAR:7-T;W,@17AP("0`)$YE=$)31#H@
M8W)T:2Y3+'8@,2XQ(#(P,3(O,#@O,3,@,#(Z-#DZ,#0@;6%T="!%>'`@)``D
M3F5T0E-$.B!C<G1B96=I;BYC+'8@,2XQ-R`R,#$X+S$R+S(X(#$X.C$W.C$Q
M(&-H<FES=&]S($5X<"`D`"1.971"4T0Z(&-R=&5N9"Y3+'8@,2XR(#(P,3,O
M,3(O,C`@,34Z,S4Z-#@@:F]E<F<@17AP("0`````\<\"````````````````
M``@````(````"`````@````;`````0``````````*BHJ($YO($QA8F5L(%!R
M;W9I9&5D("HJ*@``\<\"``````````````````@````(````"`````@````;
M`````0``````````*BHJ($YO($QA8F5L(%!R;W9I9&5D("HJ*@!!-P```&%E
M86)I``$M````!4%233$Q-S9*6D8M4P`&!P@!"0$*`A($%`$5`1<#&`$:`AP!
M(@%$`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92YN971B<V0N:61E;G0`+FYO
M=&4N;F5T8G-D+G!A>``N;F]T92YN971B<V0N;6%R8V@`+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YT97AT`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+FIC<@`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+E-53E=?
M8W1F`"Y!4DTN871T<FEB=71E<P``````````````````````````````````
M````````````````````"P````$````"````%`$``!0!```7````````````
M```!`````````!,````'`````@```"P!```L`0``&```````````````!```
M```````F````!P````(```!$`0``1`$``!0```````````````0`````````
M-P````<````"````6`$``%@!```@```````````````$`````````$H````%
M`````@```'@!``!X`0``/`,```8`````````!`````0```!0````"P````(`
M``"T!```M`0``,`&```'`````P````0````0````6`````,````"````=`L`
M`'0+``#K!``````````````!`````````&`````)`````@```&`0``!@$```
M*`$```8`````````!`````@```!I````"0```$(```"($0``B!$``!@"```&
M````$P````0````(````;0````$````&````H!,``*`3```X`P``````````
M```$````!````'(````!````!@```-@6``#8%@``\"\`````````````!```
M``````!X`````0````(```#(1@``R$8``-Q```````````````0`````````
M@`````$````"````I(<``*2'```,`0`````````````$`````````(X````!
M`````@```+"(``"PB```\`4`````````````!`````````"8````#@````,`
M``"@C@$`H(X```0```````````````0````$````I`````\````#````I(X!
M`*2.```$```````````````$````!````+`````!`````P```*B.`0"HC@``
M!```````````````!`````````"U````!@````,```"LC@$`K(X``/`````'
M``````````0````(````O@````$````#````G(\!`)R/``!T`0``````````
M```$````!````,,````!`````P```!"1`0`0D0``2```````````````!```
M``````#)````"`````,```"`D0$`6)$``$0``````````````$``````````
MS@````$````P`````````%B1```[```````````````!`````0```!\````!
M``````````````"3D0``(@$``````````````0````````#7`````0``````
M````````N)(``(\```````````````0`````````X0````,``'``````````
M`$>3```X```````````````!``````````$````#``````````````!_DP``
4\0```````````````0``````````
